@@ -1,5 +1,5 @@
 package JSON::Path::Evaluator;
-$JSON::Path::Evaluator::VERSION = '1.0.3';
+$JSON::Path::Evaluator::VERSION = '1.0.5';
 use strict;
 use warnings;
 
@@ -671,7 +671,7 @@ JSON::Path::Evaluator - A module that recursively evaluates JSONPath expressions
 
 =head1 VERSION
 
-version 1.0.3
+version 1.0.5
 
 =head1 SYNOPSIS
 
@@ -937,11 +937,11 @@ JSONPath uses the token '@' to refer to the current node. This is also not valid
 
 =head1 AUTHOR
 
-Kit Peters <popefelix@gmail.com>
+Aurelia Peters <popefelix@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by Kit Peters.
+This software is copyright (c) 2024 by Aurelia Peters.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
